
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.14.4'
version = '1.14.4'
full_version = '1.14.4'
git_revision = 'ae4e9e936b80e03997c10ed860cb07434ea6ed02'
release = True

if not release:
    version = full_version
